@@ -24,6 +24,10 @@
 #include <string.h>
 
 #include <leptonica/allheaders.h>
+#if (LIBLEPT_MAJOR_VERSION == 1 && LIBLEPT_MINOR_VERSION >= 83) || LIBLEPT_MAJOR_VERSION > 1
+#include "leptonica/pix_internal.h"
+#include "leptonica/array_internal.h"
+#endif
 
 #include <math.h>
 #if defined(sun)
@@ -149,7 +153,7 @@ print_list(std::list<int> &l) {
 #endif
 
 // -----------------------------------------------------------------------------
-// unite_templates unites templates of the same character to chosen charater
+// unite_templates unites templates of the same character to chosen character
 // template
 //
 //   ctx: structure containing templates of symbols.
@@ -206,7 +210,11 @@ unite_templates(struct jbig2ctx *ctx,
         numaSetValue(ctx->classer->naclass, i, new_representant);
       }
     }
+#if (LIBLEPT_MAJOR_VERSION == 1 && LIBLEPT_MINOR_VERSION >= 83) || LIBLEPT_MAJOR_VERSION > 1
+    ctx->classer->pixat->pix[new_representant]->refcount += ctx->classer->pixat->pix[second_template]->refcount;
+#else
     pixChangeRefcount(ctx->classer->pixat->pix[new_representant],pixGetRefcount(ctx->classer->pixat->pix[second_template]));
+#endif
   }
   return 0;
 }
@@ -367,7 +375,7 @@ jbig2enc_auto_threshold(struct jbig2ctx *ctx) {
   }
 }
 
-#if defined(HASH_DEBUGING)
+#if defined(HASH_DEBUGGING)
 static void
 print_hash_map(std::map<unsigned int, list<int> > &hashed_templates) {
   std::map<unsigned int, list<int> >::iterator it;
@@ -430,7 +438,7 @@ jbig2enc_auto_threshold_using_hash(struct jbig2ctx *ctx) {
     count_hash(pixa->pix[i], hashed_templates, i);
   }
 
-  #ifdef HASH_DEBUGING
+  #ifdef HASH_DEBUGGING
     print_hash_map(hashed_templates);
   #endif
 
@@ -527,10 +535,10 @@ jbig2_add_page(struct jbig2ctx *ctx, struct Pix *input) {
 
 // see comments in .h file
 uint8_t *
-jbig2_pages_complete(struct jbig2ctx *ctx, int *const length) {
+jbig2_pages_complete(struct jbig2ctx *ctx, int *const length, bool verbose) {
   /*
      Graying support - disabled.
-     It's not very clear that graying actaully buys you much extra quality
+     It's not very clear that graying actually buys you much extra quality
      above pick-the-first. Also, aligning the gray glyphs requires the
      original source image.
 
@@ -651,10 +659,11 @@ jbig2_pages_complete(struct jbig2ctx *ctx, int *const length) {
     pixWrite(filenamebuf, ctx->classer->pixat->pix[i], IFF_PNG);
   }
 #endif
-  fprintf(stderr, "JBIG2 compression complete. pages:%d symbols:%d log2:%d\n",
-          ctx->classer->npages, ctx->classer->pixat->n,
-          log2up(ctx->classer->pixat->n));
-
+  if (verbose) {
+    fprintf(stderr, "JBIG2 compression complete. pages:%d symbols:%d log2:%d\n",
+            ctx->classer->npages, ctx->classer->pixat->n,
+            log2up(ctx->classer->pixat->n));
+  }
   jbGetLLCorners(ctx->classer);
 
   struct jbig2enc_ctx ectx;
